==> jc-1.4.0.tar.gz: javax/swing/text/StyleConstants__24ParagraphConstants.h <==
// public class javax.swing.text.StyleConstants$ParagraphConstants

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33098ca6f888e073 javax_swing_text_StyleConstants
// @dep_class d7b32afcd0c5ae0 javax_swing_text_StyleConstants__24ParagraphConstants

// header file dependencies
// @dep_header javax_swing_text_StyleConstants

#include "javax/swing/text/StyleConstants.h"

#ifndef _JC_javax_swing_text_StyleConstants__24ParagraphConstants_H_
#define _JC_javax_swing_text_StyleConstants__24ParagraphConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_refs	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_refs;
typedef struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_nonrefs	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$refs	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$refs;
typedef struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$nonrefs	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$object	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$object;

typedef struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$fields_struct	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$fields_struct;
typedef const struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$vmethods	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$vmethods;
typedef const struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtable	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtable;
typedef const struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtype	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtype;

// Class fields structure
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$fields_struct {
	struct _jc_java_lang_Object$object	*Alignment;
	struct _jc_java_lang_Object$object	*FirstLineIndent;
	struct _jc_java_lang_Object$object	*LeftIndent;
	struct _jc_java_lang_Object$object	*LineSpacing;
	struct _jc_java_lang_Object$object	*Orientation;
	struct _jc_java_lang_Object$object	*RightIndent;
	struct _jc_java_lang_Object$object	*SpaceAbove;
	struct _jc_java_lang_Object$object	*SpaceBelow;
	struct _jc_java_lang_Object$object	*TabSet;
};
extern _jc_javax_swing_text_StyleConstants__24ParagraphConstants$fields_struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$class_fields;

// Constructors
extern void _jc_javax_swing_text_StyleConstants__24ParagraphConstants$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$object *, struct _jc_java_lang_String$object *);

// Static methods
extern void _jc_javax_swing_text_StyleConstants__24ParagraphConstants$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$vmethods {
};

// Vtable
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StyleConstants$vmethods	javax_swing_text_StyleConstants;
	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$vmethods	javax_swing_text_StyleConstants__24ParagraphConstants;
};

// Vtype
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$refs {
    _jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_refs	javax_swing_text_StyleConstants__24ParagraphConstants;
    _jc_javax_swing_text_StyleConstants$sub_refs	javax_swing_text_StyleConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StyleConstants$sub_nonrefs	javax_swing_text_StyleConstants;
    _jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_nonrefs	javax_swing_text_StyleConstants__24ParagraphConstants;
};

// Object instance structure
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$object {
	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtype	*vtype;
	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtype _jc_javax_swing_text_StyleConstants__24ParagraphConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyleConstants__24ParagraphConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyleConstants__24ParagraphConstants$class_object;

#endif	/* _JC_javax_swing_text_StyleConstants__24ParagraphConstants_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/StyleConstants__24ParagraphConstants.h <==
// public class javax.swing.text.StyleConstants$ParagraphConstants

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 602dc460083efcf4 javax_swing_text_StyleConstants
// @dep_class 46864499d5dcb9a javax_swing_text_StyleConstants__24ParagraphConstants

// header file dependencies
// @dep_header javax_swing_text_StyleConstants

#include "javax/swing/text/StyleConstants.h"

#ifndef _JC_javax_swing_text_StyleConstants__24ParagraphConstants_H_
#define _JC_javax_swing_text_StyleConstants__24ParagraphConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_refs	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_refs;
typedef struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_nonrefs	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$refs	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$refs;
typedef struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$nonrefs	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$object	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$object;

typedef struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$fields_struct	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$fields_struct;
typedef const struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$vmethods	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$vmethods;
typedef const struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtable	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtable;
typedef const struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtype	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtype;

// Class fields structure
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$fields_struct {
	struct _jc_java_lang_Object$object	*Alignment;
	struct _jc_java_lang_Object$object	*FirstLineIndent;
	struct _jc_java_lang_Object$object	*LeftIndent;
	struct _jc_java_lang_Object$object	*LineSpacing;
	struct _jc_java_lang_Object$object	*Orientation;
	struct _jc_java_lang_Object$object	*RightIndent;
	struct _jc_java_lang_Object$object	*SpaceAbove;
	struct _jc_java_lang_Object$object	*SpaceBelow;
	struct _jc_java_lang_Object$object	*TabSet;
};
extern _jc_javax_swing_text_StyleConstants__24ParagraphConstants$fields_struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$class_fields;

// Constructors
extern void _jc_javax_swing_text_StyleConstants__24ParagraphConstants$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_swing_text_StyleConstants__24ParagraphConstants$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$vmethods {
};

// Vtable
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StyleConstants$vmethods	javax_swing_text_StyleConstants;
	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$vmethods	javax_swing_text_StyleConstants__24ParagraphConstants;
};

// Vtype
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$refs {
    _jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_refs	javax_swing_text_StyleConstants__24ParagraphConstants;
    _jc_javax_swing_text_StyleConstants$sub_refs	javax_swing_text_StyleConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StyleConstants$sub_nonrefs	javax_swing_text_StyleConstants;
    _jc_javax_swing_text_StyleConstants__24ParagraphConstants$sub_nonrefs	javax_swing_text_StyleConstants__24ParagraphConstants;
};

// Object instance structure
struct _jc_javax_swing_text_StyleConstants__24ParagraphConstants$object {
	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtype	*vtype;
	_jc_javax_swing_text_StyleConstants__24ParagraphConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyleConstants__24ParagraphConstants$vtype _jc_javax_swing_text_StyleConstants__24ParagraphConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyleConstants__24ParagraphConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyleConstants__24ParagraphConstants$class_object;

#endif	/* _JC_javax_swing_text_StyleConstants__24ParagraphConstants_H_ */
